@@ -3,11 +3,7 @@
 import { configure } from 'enzyme';
 import * as Adapter from 'enzyme-adapter-react-16';
 
+import 'url-search-params-polyfill';
+
 // http://airbnb.io/enzyme/docs/installation/index.html#working-with-react-16
-configure({adapter: new Adapter()});
-
-window.SERVER_FLAGS = {
-  basePath: '/',
-};
-
-require('url-search-params-polyfill');
+configure({ adapter: new Adapter() });
