@@ -2,9 +2,9 @@ import { $, $$, browser, ExpectedConditions as until } from 'protractor';
 
 const BROWSER_TIMEOUT = 15000;
 
-export const dropdown = $('.co-type-selector .btn-dropdown');
-export const dropdownLinks = $$('.dropdown-menu a');
-export const labelFilter = $('.co-m-selector-input input');
+export const dropdown = $('.co-type-selector .pf-c-dropdown__toggle');
+export const dropdownLinks = $$('.pf-c-dropdown__menu a');
+export const labelFilter = $('.co-search-input input');
 export const linkForType = type => $(`#${type}-link`);
 
 export const selectSearchType = async(objectType: string) => {
