@@ -1,5 +1,3 @@
-/* eslint-disable no-undef, no-unused-vars */
-
 import * as React from 'react';
 import * as _ from 'lodash-es';
 
@@ -10,7 +8,7 @@ import { SubscriptionKind, PackageManifestKind } from '../operator-lifecycle-man
 import { SubscriptionModel, ClusterServiceVersionModel } from '../../models';
 import { RadioInput } from '../radio';
 
-export class SubscriptionChannelModal extends PromiseComponent {
+export class SubscriptionChannelModal extends PromiseComponent<SubscriptionChannelModalProps, SubscriptionChannelModalState> {
   public state: SubscriptionChannelModalState;
 
   constructor(public props: SubscriptionChannelModalProps) {
@@ -53,8 +51,8 @@ export class SubscriptionChannelModal extends PromiseComponent {
 export const createSubscriptionChannelModal = createModalLauncher<SubscriptionChannelModalProps>(SubscriptionChannelModal);
 
 export type SubscriptionChannelModalProps = {
-  cancel: (e: Event) => void;
-  close: () => void;
+  cancel?: () => void;
+  close?: () => void;
   k8sUpdate: (kind: K8sKind, newObj: K8sResourceKind) => Promise<any>;
   subscription: SubscriptionKind;
   pkg: PackageManifestKind;
