@@ -3,7 +3,8 @@ import * as React from 'react';
 import { Helmet } from 'react-helmet';
 import { Link } from 'react-router-dom';
 import { ActionGroup, Button } from '@patternfly/react-core';
-
+import { isCephProvisioner } from '@console/shared/src/utils';
+import { filterScOnProvisioner } from '@console/shared';
 import { k8sCreate, K8sResourceKind, referenceFor } from '../../module/k8s';
 import {
   AsyncComponent,
@@ -16,24 +17,27 @@ import { StorageClassDropdown } from '../utils/storage-class-dropdown';
 import { RadioInput } from '../radio';
 import { Checkbox } from '../checkbox';
 import { PersistentVolumeClaimModel } from '../../models/index';
+import { StorageClass } from '../storage-class-form';
 
 const NameValueEditorComponent = (props) => <AsyncComponent loader={() => import('../utils/name-value-editor').then(c => c.NameValueEditor)} {...props} />;
 
+const cephRBDProvisionerSuffix = 'rbd.csi.ceph.com';
+
 //See https://kubernetes.io/docs/concepts/storage/persistent-volumes/#types-of-persistent-volumes for more details
 const provisionerAccessModeMapping = {
   'kubernetes.io/no-provisioner': ['ReadWriteOnce'],
-  'kubernetes.io/aws-ebs' : ['ReadWriteOnce'],
-  'kubernetes.io/gce-pd' : ['ReadWriteOnce', 'ReadOnlyMany'],
-  'kubernetes.io/glusterfs' : ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
-  'kubernetes.io/cinder' : ['ReadWriteOnce'],
-  'kubernetes.io/azure-file' : ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
-  'kubernetes.io/azure-disk' : ['ReadWriteOnce'],
-  'kubernetes.io/quobyte' : ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
-  'kubernetes.io/rbd' : ['ReadWriteOnce', 'ReadOnlyMany'],
-  'kubernetes.io/vsphere-volume' : ['ReadWriteOnce', 'ReadWriteMany'],
-  'kubernetes.io/portworx-volume' : ['ReadWriteOnce', 'ReadWriteMany'],
-  'kubernetes.io/scaleio' : ['ReadWriteOnce', 'ReadOnlyMany'],
-  'kubernetes.io/storageos' : ['ReadWriteOnce'],
+  'kubernetes.io/aws-ebs': ['ReadWriteOnce'],
+  'kubernetes.io/gce-pd': ['ReadWriteOnce', 'ReadOnlyMany'],
+  'kubernetes.io/glusterfs': ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
+  'kubernetes.io/cinder': ['ReadWriteOnce'],
+  'kubernetes.io/azure-file': ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
+  'kubernetes.io/azure-disk': ['ReadWriteOnce'],
+  'kubernetes.io/quobyte': ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'],
+  'kubernetes.io/rbd': ['ReadWriteOnce', 'ReadOnlyMany'],
+  'kubernetes.io/vsphere-volume': ['ReadWriteOnce', 'ReadWriteMany'],
+  'kubernetes.io/portworx-volume': ['ReadWriteOnce', 'ReadWriteMany'],
+  'kubernetes.io/scaleio': ['ReadWriteOnce', 'ReadOnlyMany'],
+  'kubernetes.io/storageos': ['ReadWriteOnce'],
 };
 
 // This form is done a little odd since it is used in both its own page and as
@@ -69,6 +73,7 @@ export class CreatePVCForm extends React.Component<CreatePVCFormProps, CreatePVC
       Gi: 'Gi',
       Ti: 'Ti',
     },
+    storageProvisioner: '',
   };
 
   handleChange: React.ReactEventHandler<HTMLInputElement> = event => {
@@ -81,15 +86,22 @@ export class CreatePVCForm extends React.Component<CreatePVCFormProps, CreatePVC
     this.setState({ nameValuePairs }, this.onChange);
   };
 
+  getAccessModeForProvisioner = (provisioner: string) => {
+    return provisioner && isCephProvisioner(provisioner)
+      ? ['ReadWriteOnce', 'ReadWriteMany']
+      : ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'];
+  };
+
   handleStorageClass = storageClass => {
     //if the provisioner is unknown or no storage class selected, user should be able to set any access mode
-    const modes = storageClass && storageClass.provisioner && provisionerAccessModeMapping[storageClass.provisioner] ? provisionerAccessModeMapping[storageClass.provisioner] : ['ReadWriteOnce', 'ReadWriteMany', 'ReadOnlyMany'];
+    const modes = storageClass && storageClass.provisioner && provisionerAccessModeMapping[storageClass.provisioner] ? provisionerAccessModeMapping[storageClass.provisioner] : this.getAccessModeForProvisioner(storageClass.provisioner);
     //setting message to display for various modes when a storage class of a know provisioner is selected
-    const displayMessage = storageClass && provisionerAccessModeMapping[storageClass.provisioner] ? 'Access mode is set by storage class and cannot be changed.': 'Permissions to the mounted drive.';
+    const displayMessage = (provisionerAccessModeMapping[storageClass.provisioner] ||
+      isCephProvisioner(storageClass.provisioner)) ? 'Access mode is set by storage class and cannot be changed.' : 'Permissions to the mounted drive.';
     this.setState({ accessModeHelp: displayMessage }, this.onChange);
 
     //setting accessMode to default with the change to Storage Class selection
-    this.setState({ storageClass: _.get(storageClass, 'metadata.name'), allowedAccessModes: modes, accessMode: 'ReadWriteOnce'}, this.onChange);
+    this.setState({ storageClass: _.get(storageClass, 'metadata.name'), allowedAccessModes: modes, accessMode: 'ReadWriteOnce', storageProvisioner: storageClass && storageClass.provisioner}, this.onChange);
   };
 
   handleRequestSizeInputChange = obj => {
@@ -119,7 +131,7 @@ export class CreatePVCForm extends React.Component<CreatePVCFormProps, CreatePVC
 
   updatePVC = () => {
     const { namespace } = this.props;
-    const { pvcName, accessMode, requestSizeValue, requestSizeUnit, storageClass } = this.state;
+    const { pvcName, accessMode, requestSizeValue, requestSizeUnit, storageClass, storageProvisioner } = this.state;
     const obj: K8sResourceKind = {
       apiVersion: 'v1',
       kind: 'PersistentVolumeClaim',
@@ -145,11 +157,21 @@ export class CreatePVCForm extends React.Component<CreatePVCFormProps, CreatePVC
 
     if (storageClass) {
       obj.spec.storageClassName = storageClass;
+
+      // should set block only for RBD + RWX
+      if (
+        _.endsWith(storageProvisioner, cephRBDProvisionerSuffix) &&
+        accessMode === 'ReadWriteMany'
+      ) {
+        obj.spec.volumeMode = 'Block';
+      }
     }
 
     return obj;
   };
 
+  onlyPvcSCs = (sc: StorageClass) => filterScOnProvisioner(sc, 'noobaa.io/obc');
+
   render() {
     const { accessMode, dropdownUnits, useSelector, nameValuePairs, requestSizeUnit, requestSizeValue, allowedAccessModes } = this.state;
 
@@ -162,6 +184,7 @@ export class CreatePVCForm extends React.Component<CreatePVCFormProps, CreatePVC
             describedBy="storageclass-dropdown-help"
             required={false}
             name="storageClass"
+            filter={this.onlyPvcSCs}
           />
         </div>
         <label className="control-label co-required" htmlFor="pvc-name">
@@ -210,7 +233,7 @@ export class CreatePVCForm extends React.Component<CreatePVCFormProps, CreatePVC
             return radioObj;
           })}
           <p className="help-block" id="access-mode-help">
-            {this.state.accessModeHelp }
+            {this.state.accessModeHelp}
           </p>
         </div>
         <label className="control-label co-required" htmlFor="request-size-input">
@@ -352,6 +375,7 @@ export type CreatePVCFormState = {
   useSelector: boolean;
   nameValuePairs: string[][];
   accessModeHelp: string;
+  storageProvisioner: string;
 };
 
 export type CreatePVCPageProps = {
