@@ -1,7 +1,7 @@
-/* eslint-disable no-undef, no-unused-vars */
-
 import * as _ from 'lodash-es';
-import { createBrowserHistory, createMemoryHistory } from 'history';
+import { createBrowserHistory, createMemoryHistory, History } from 'history';
+
+type AppHistory = History & {pushPath: History['push']};
 
 let createHistory;
 
@@ -17,19 +17,19 @@ try {
   createHistory = createBrowserHistory;
 }
 
-export const history = createHistory({basename: (window as any).SERVER_FLAGS.basePath});
+export const history: AppHistory = createHistory({basename: window.SERVER_FLAGS.basePath});
 
-const removeBasePath = (url = '/') => _.startsWith(url, (window as any).SERVER_FLAGS.basePath)
-  ? url.slice((window as any).SERVER_FLAGS.basePath.length - 1)
+const removeBasePath = (url = '/') => _.startsWith(url, window.SERVER_FLAGS.basePath)
+  ? url.slice(window.SERVER_FLAGS.basePath.length - 1)
   : url;
 
 // Monkey patch history to slice off the base path
-history.__replace__ = history.replace;
-history.replace = url => history.__replace__(removeBasePath(url));
+(history as any).__replace__ = history.replace;
+history.replace = url => (history as any).__replace__(removeBasePath(url));
 
-history.__push__ = history.push;
-history.push = url => history.__push__(removeBasePath(url));
-history.pushPath = path => history.__push__(path);
+(history as any).__push__ = history.push;
+history.push = url => (history as any).__push__(removeBasePath(url));
+(history as any).pushPath = path => (history as any).__push__(path);
 
 export const getQueryArgument = (arg: string) => new URLSearchParams(window.location.search).get(arg);
 
@@ -40,6 +40,13 @@ export const setQueryArgument = (k: string, v: string) => {
   history.replace(`${url.pathname}?${params.toString()}${url.hash}`);
 };
 
+export const setAllQueryArguments = (newParams: {[k: string]: string}) => {
+  const params = new URLSearchParams();
+  _.each(newParams, (v, k) => params.set(k, v));
+  const url = new URL(window.location.href);
+  history.replace(`${url.pathname}?${params.toString()}${url.hash}`);
+};
+
 export const removeQueryArgument = (k: string) => {
   const params = new URLSearchParams(window.location.search);
   params.delete(k);
